import 'dart:io';

import 'package:flutter/material.dart';

class AppTheme {
  AppTheme._();
/**#660000
#AA0A0A */
  static const Color _lightPrimaryColor = Color(0xFF660000);
  static const Color _lightSecondaryColor = Color(0xFFAA0A0A);
  static const Color _lightOnPrimaryColor = Colors.white;
  static const Color _lightOnSecondaryColor = Colors.white;
  static const Color _lightTextInputColor = Colors.white;
  static const Color _lightSurfaceColor = Color(0xFFF2F0F7);
  static const Color _lightHintTextColor = Color(0xFFCFCFCF);

  static const Color _darkPrimaryColor = Colors.white24;
  static const Color _darkSecondaryColor = Color(0xFFAA0A0A);
  static const Color _darkOnPrimaryColor = Colors.white;
  static const Color _darkPrimaryVariantColor = Colors.black;
  static const Color _darkOnSecondaryColor = Colors.white;
  static const Color _darkSurfaceColor = Color(0xFF1D2B4E);

  static const Map<int, Color> granate = <int, Color>{
    50: Color(0XFFFFE7E5),
    100: Color(0xFFF9D8C7),
    200: Color(0xFFF3AB91),
    300: Color(0xFFDB6E57),
    400: Color(0xFFB83A2E),
    500: Color(0xFF990301),
    600: Color(0xFF75000A),
    700: Color(0xFF620011),
    800: Color(0xFF4F0014),
    900: Color(0xFF410016)
  };

  static const Map<int, Color> naranja = <int, Color>{
    100: Color(0xFFFEF1D3),
    200: Color(0xFFFEDFA8),
    300: Color(0xFFFDC77D),
    400: Color(0xFFFBB15C),
    500: Color(0xFFF1882D),
    600: Color(0xFFD66C1C),
    700: Color(0xFFB34F13),
    800: Color(0xFF90370C),
    900: Color(0xFF772607)
  };

  static const Map<int, Color> grey = <int, Color>{
    50: Color(0xFFF2F0F7),
    100: Color(0xFFF2F2F2),
    200: Color(0xFFF5F5F5),
    300: Color(0xFFD3D3D3),
    400: Color(0xFFB4B4B4),
    500: Color(0xFF858488),
    600: Color(0xFF404040),
    700: Color(0xFF333333),
    800: Color(0xFF260000),
    900: Color(0xFF190000),
  };
  static const Map<int, Color> marino = <int, Color>{
    100: Color(0xFFD3DCF5),
    200: Color(0xFFA9B9EC),
    300: Color(0xFF7385C7),
    400: Color(0xFF445390),
    500: Color(0xFF1D2B4E),
    600: Color(0xFF0F163D),
    700: Color(0xFF0A1033),
    800: Color(0xFF060A29),
    900: Color(0xFF040722),
  };
  static Color getSecondaryColor() {
    return _lightSecondaryColor;
  }

  static final ThemeData customLightTheme = ThemeData(
    //brightness: Brightness.light,
    //primarySwatch: MaterialColor(0xFF151E47, CompanyColors.marino),
    appBarTheme: const AppBarTheme(
      backgroundColor: _lightPrimaryColor,
    ),
    fontFamily: 'Roboto',
    colorScheme: const ColorScheme.light(
      primary: _lightPrimaryColor,
      onPrimary: _lightOnPrimaryColor,
      secondary: _lightSecondaryColor,
      onSecondary: _lightOnSecondaryColor,
      background: _lightPrimaryColor,
      onBackground: Colors.white,
      surface: _lightSurfaceColor,
      onSurface: Colors.black,
      error: Colors.red,
      onError: Colors.white,
    ),
    primaryColor: _lightPrimaryColor,
    cardColor: _lightSurfaceColor,
    scaffoldBackgroundColor: Colors.white,
    inputDecorationTheme: _lightInputDecorationTheme,
    elevatedButtonTheme: _lightElevatedButtonThemeData,
    textButtonTheme: _lightTextButtonThemeData,
    textTheme: _lightTextTheme,
    floatingActionButtonTheme: _lightFloatingActionButtonTheme,
  );

  static final _lightTextButtonThemeData = TextButtonThemeData(
    style: TextButton.styleFrom(
        primary: _lightPrimaryColor,
        textStyle: const TextStyle(fontSize: 14, fontWeight: FontWeight.bold)),
  );
  static final TextTheme _lightTextTheme = TextTheme(
    bodyText1: TextStyle(
      fontSize: 16,
      color: Colors.black,
    ),
    bodyText2: TextStyle(
      fontSize: 14,
      color: Colors.black,
    ),
    button: TextStyle(fontSize: 16, fontWeight: FontWeight.bold),
  );
  static final _lightElevatedButtonThemeData = ElevatedButtonThemeData(
    style: ElevatedButton.styleFrom(
      elevation: 0,
      minimumSize: const Size.fromHeight(45),
      primary: _lightSecondaryColor,
      onPrimary: _lightOnSecondaryColor,
      textStyle: const TextStyle(
        fontWeight: FontWeight.w500,
        fontSize: 16,
      ),
    ),
  );
  static final _lightFloatingActionButtonTheme = FloatingActionButtonThemeData(
    elevation: 5,
    backgroundColor: _lightPrimaryColor,
    iconSize: 24,
  );
  static final _lightInputDecorationTheme = InputDecorationTheme(
    prefixIconColor: _lightHintTextColor, //GRAY500
    border: const OutlineInputBorder(
      borderSide: BorderSide.none,
      borderRadius: BorderRadius.all(
        Radius.circular(5),
      ),
    ),
    focusedBorder: const OutlineInputBorder(
      borderSide: BorderSide(color: _lightPrimaryColor, width: 1),
      borderRadius: BorderRadius.all(
        Radius.circular(5),
      ),
    ),
    disabledBorder: OutlineInputBorder(
      borderSide: BorderSide(color: _lightPrimaryColor, width: .3),
      borderRadius: BorderRadius.all(
        Radius.circular(5),
      ),
    ),
    suffixIconColor: _lightHintTextColor,
    filled: true,
    hintStyle: TextStyle(
        fontWeight: FontWeight.bold, color: _lightHintTextColor, fontSize: 14),
    fillColor: _lightTextInputColor,
    floatingLabelStyle: const TextStyle(
      color: Color(0xFFAA0A0A),
      fontWeight: FontWeight.bold,
    ),
    errorStyle: TextStyle(
      color: Colors.red,
      fontSize: 12,
      fontWeight: FontWeight.bold,
      fontFamily: 'Roboto',
    ),
    labelStyle: const TextStyle(
      color: Color(0xFFAA0A0A),
      fontSize: 12,
      fontWeight: FontWeight.bold,
    ),
    errorMaxLines: 1,
  );

  static final ThemeData customDarkTheme = ThemeData(
    //brightness: Brightness.light,
    //primarySwatch: MaterialColor(0xFF151E47, CompanyColors.marino),
    appBarTheme: AppBarTheme(backgroundColor: _darkPrimaryColor),
    fontFamily: 'Roboto',
    colorScheme: const ColorScheme.dark(
      primary: _darkPrimaryColor,
      onPrimary: _darkOnPrimaryColor,
      secondary: _darkSecondaryColor,
      onSecondary: _darkOnSecondaryColor,
      background: _darkPrimaryColor,
      onBackground: Colors.white,
      surface: _darkSurfaceColor,
      onSurface: Colors.white,
      error: Colors.red,
      onError: Colors.white,
    ),
    primaryColor: _darkPrimaryColor,
    cardColor: _darkSurfaceColor,
    //scaffoldBackgroundColor: grey[300],
    scaffoldBackgroundColor: _darkPrimaryVariantColor,
    // backgroundColor: CompanyColors.grey[200],
    //indicatorColor: CompanyColors.granate[500],
    /*inputDecorationTheme: _lightInputDecorationTheme,
    elevatedButtonTheme: _lightElevatedButtonThemeData,
    textButtonTheme: _lightTextButtonThemeData,
    textTheme: _lightTextTheme,
    floatingActionButtonTheme: _lightFloatingActionButtonTheme,*/
  );
}
