import 'dart:io';
import 'package:dio/dio.dart';
import 'package:cookie_jar/cookie_jar.dart';
import 'package:dio_cookie_manager/dio_cookie_manager.dart';
import 'ConectionApi.dart';

class RemoteClient {
  String apiUrl = "https://tramites.una.py/etramite-backend/";
  ConectionApi conection = ConectionApi();

  String getApiUrl() {
    return apiUrl;
  }

  Future<Response?> post(
      String method, dynamic params, Map<String, dynamic> body) async {
    var request = FormData.fromMap(body);
    print('comienza el metodo post $method');
    var options = Options(
      followRedirects: false,
      validateStatus: (status) => true,
    );
    Dio _dio = Dio();
    CookieJar _cookieJar = CookieJar();
    _dio.interceptors.add(CookieManager(_cookieJar));
    try {
      if (method != 'login' &&
          method != 'login/google' &&
          method != 'registrarse') {
        List<Cookie> cookie = await conection.getCookie();
        await _cookieJar.saveFromResponse(Uri.parse(getApiUrl()), cookie);
        await _cookieJar.loadForRequest(Uri.parse(getApiUrl()));
      }
      Response response = await _dio.post(getApiUrl() + method,
          data: request, queryParameters: params, options: options);
      //print('Respuesta post method $method : $response');

      if (method == 'login' || method == 'login/google') {
        var con = await _cookieJar.loadForRequest(Uri.parse(getApiUrl()));
        //print('connnn $con');
        conection.setCookie(con);
        //await conection.getCookieJar().saveFromResponse(Uri.parse(getApiUrl()), get);
      }

      //print('statuscode ${response.statusCode}, headers: ${response.headers.toString()}');
      print('Respuesta post method $method status ${response.statusCode}');
      return response;
    } catch (e) {
      print('Errorrrrr : $e');
      return null;
    }
  }

  Future<Response?> get(String method, params) async {
    print('comienza el metodo get $method');
    var options = Options(
      followRedirects: false,
      validateStatus: (status) => true,
    );
    Dio _dio = Dio();
    CookieJar _cookieJar = CookieJar();
    _dio.interceptors.add(CookieManager(_cookieJar));
    try {
      var cookie = await conection.getCookie();
      await _cookieJar.saveFromResponse(Uri.parse(getApiUrl()), cookie);
      await _cookieJar.loadForRequest(Uri.parse(getApiUrl()));

      Response response = await _dio.get(getApiUrl() + method,
          options: options, queryParameters: params);
      print('Respuesta get method $method status ${response.statusCode}');
      return response;
    } catch (e) {
      print('Error: $e');
      return null;
    }
  }

  Future<Response?> download(String method, int mode, String path) async {
    print('comienza el metodo download $method');
    var url = getApiUrl() + method;
    Dio _dio = Dio();
    CookieJar _cookieJar = CookieJar();
    _dio.interceptors.add(CookieManager(_cookieJar));
    try {
      var cookie = await conection.getCookie();
      await _cookieJar.saveFromResponse(Uri.parse(getApiUrl()), cookie);
      await _cookieJar.loadForRequest(Uri.parse(getApiUrl()));

      Response response = await _dio.get(url,
          onReceiveProgress: showDownloadProgress,
          options: Options(
            followRedirects: false,
            validateStatus: (status) => true,
          ));
      //print(response.data);
      return response;
    } catch (e) {
      print("error  + $e");
      return null;
    }
  }

  Future<Response?> delete(String method, params) async {
    print('comienza el metodo delete $method');
    var options = Options(
      followRedirects: false,
      validateStatus: (status) => true,
    );
    Dio _dio = Dio();
    CookieJar _cookieJar = CookieJar();
    _dio.interceptors.add(CookieManager(_cookieJar));
    try {
      var cookie = await conection.getCookie();
      await _cookieJar.saveFromResponse(Uri.parse(getApiUrl()), cookie);
      await _cookieJar.loadForRequest(Uri.parse(getApiUrl()));

      Response response = await _dio.delete(getApiUrl() + method,
          options: options, queryParameters: params);
      print('Respuesta delete method $method status ${response.statusCode}');
      return response;
    } catch (e) {
      print('Error: $e');
      return null;
    }
  }
}

void showDownloadProgress(received, total) {
  if (total != -1) {
    //print((received / total * 100).toStringAsFixed(0) + "%");
  }
}
 /* (_dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate =
          (HttpClient client) {
        client.badCertificateCallback =
            (X509Certificate cert, String host, int port) => true;
        return client;
      };*/