import 'package:ealu_flutter/presentation/blocs/login/login_bloc.dart';

import '../../core/responsesError.dart';
import '../../domain/entities/user.dart';
import '../../domain/repositories/auth_repository.dart';
import '../../presentation/widgets/toast.dart';
import '../datasources/login_data_source.dart';

class AuthRepositoryImpl implements AuthRepository {
  final DataSourceLogin remote;

  AuthRepositoryImpl(this.remote);

  @override
  Future<User?> login(String email, String password) async {
    try {
      final loginModel = await remote.remoteloginUser(email, password);
      final user = User.fromModel(loginModel!.userModel);
      //await localDataSource.cacheAuth(Auth);
      return user;
    } on UnauthorizedException {
      showToastError("No autorizado");
      return null;
    } on ServerException {
      showToastError("Error de servidor");
      return null;
    } on Exception {
      showToastError("Error desconocido'");
      return null;
    }
  }

  @override
  Future<User?> sessionInfo() async {
    try {
      final loginModel = await remote.remoteSessionInfo(email, password);
      final user = User.fromModel(loginModel!.userModel);
      //await localDataSource.cacheAuth(Auth);
      return user;
    } on UnauthorizedException {
      showToastError("No autorizado");
      return null;
    } on ServerException {
      showToastError("Error de servidor");
      return null;
    } on Exception {
      showToastError("Error desconocido'");
      return null;
    }
  }
}
