import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:sizer/sizer.dart';
import 'core/AppTheme.dart';
import 'core/router.dart';
import 'data/datasources/login_data_source.dart';
import 'data/repositories/auth_repository.dart';
import 'domain/repositories/auth_repository.dart';
import 'domain/usecases/authentication_case_use.dart';
import 'presentation/blocs/authentication/authentication_bloc.dart';
import 'presentation/blocs/authentication/authentication_event.dart';
import 'presentation/blocs/authentication/authentication_state.dart';
import 'presentation/blocs/login/login_bloc.dart';
import 'presentation/screens/home/sc_homeScreen.dart';
import 'presentation/screens/login/sc_loginScreen.dart';
import 'presentation/screens/splash/sc_splash.dart';

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Sizer(
      builder: (context, orientation, deviceType) {
        return MaterialApp(
          /* localizationsDelegates: [
            GlobalMaterialLocalizations.delegate,
            GlobalWidgetsLocalizations.delegate,
            GlobalCupertinoLocalizations.delegate,
          ],*/
          supportedLocales: [
            Locale('es'), // Spanish
          ],
          theme: AppTheme.customLightTheme,
          onGenerateRoute: AppRouter.generateRoute,
          home: BlocBuilder<AuthenticationBloc, AuthenticationState>(
            builder: (context, state) {
              if (state is Uninitialized) {
                return SplashScreen();
              } else if (state is Unauthenticated) {
                return LoginScreen();
              } else if (state is Authenticated) {
                return HomeScreen();
              }

              return Container(
                child: Center(child: Text('Unhandle State $state')),
              );
            },
          ),
        );
      },
    );
  }

  static Widget runWidget() {
    return FutureBuilder(
      future: Future.sync(() => true),
      builder: (context, snapshot) {
        if (snapshot.hasData) {
          return MultiRepositoryProvider(
            providers: [
              RepositoryProvider<DataSourceLogin>(
                create: (context) => DataSourceLogin(),
              ),
              RepositoryProvider<AuthRepository>(
                create: (context) => AuthRepositoryImpl(
                  context.read<DataSourceLogin>(),
                ),
              ),
              /*RepositoryProvider<TimerRepository>(
                  create: (context) => timerRepository),
              RepositoryProvider<ProductsRepository>(
                  create: (context) => productsRepository),
              RepositoryProvider<HomeRepository>(
                  create: (context) => homeRepository),
              RepositoryProvider<ShowRepository>(
                  create: (context) => showRepository),
              RepositoryProvider<BookTimeSlotRepository>(
                  create: (context) => bookTimeSlotRepository),
              RepositoryProvider<SessionRepository>(
                  create: (context) => sessionRepository),
              RepositoryProvider<SeatSlotRepository>(
                  create: (context) => seatSlotRepository),*/
            ],
            child: MultiBlocProvider(
              providers: [
                BlocProvider(
                  create: (context) => AuthenticationBloc()..add(AppStarted()),
                ),
                /*BlocProvider(
                  create: (context) => HomeBloc(
                    homeRepository: homeRepository,
                    userRepository: userRepository,
                  ),
                ),*/
                BlocProvider(
                  create: (context) => LoginBloc(
                    authUseCase: LoginUseCase(
                      authRepository: context.read<AuthRepository>(),
                    ),
                  ),
                )
              ],
              child: MyApp(),
            ),
          );
        }
        return Container();
      },
    );
  }
}
