import 'package:flutter/material.dart';

class MatriculaSelect extends StatefulWidget {
  final Function handleHomeRefresh;
  final GlobalKey<NavigatorState> navigatorKey;

  MatriculaSelect({required this.handleHomeRefresh, required this.navigatorKey});

  @override
  _MatriculaSelectState createState() => _MatriculaSelectState();
}

class _MatriculaSelectState extends State<MatriculaSelect> {
  late Store<AppState> _store;
  late String _currentMatriculaCodcarsec;
  late int _currentMatriculaIndex;
  late bool _visible;
  late final _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    super.initState();
    _visible = false;
  }

  @override
  Widget build(BuildContext context) {
    _store = StoreProvider.of<AppState>(context);
    final sessionInfo = _store.state.auth.sessionInfo;
    final currentMatricula = _store.state.auth.currentMatricula;
    final isFetching = _store.state.auth.isFetching;

    if (currentMatricula != null) {
      _currentMatriculaCodcarsec = currentMatricula.codcarsec.trim() + ' - ' + currentMatricula.carrera.trim();
      _currentMatriculaIndex = sessionInfo.matriculaList.indexWhere((matricula) => matricula.codcarsec == currentMatricula.codcarsec);
    }

    return !_visible && currentMatricula != null
        ? _buildCurrentMatricula()
        : sessionInfo == null || isFetching
            ? SizedBox.shrink()
            : _buildOverflowMenu(sessionInfo);
  }

  Widget _buildCurrentMatricula() {
    return Container(
      decoration: BoxDecoration(
        color: Theme.of(context).primaryColor,
        borderRadius: BorderRadius.circular(25.0),
      ),
      child: InkWell(
        onTap: () => setState(() => _visible = true),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            Padding(
              padding: EdgeInsets.all(10.0),
              child: Text(
                _currentMatriculaCodcarsec,
                style: TextStyle(color: Colors.white),
              ),
            ),
            Padding(
              padding: EdgeInsets.only(right: 10.0),
              child: Icon(
                Icons.ac_unit,
                color: Colors.white,
                size: 24,
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildOverflowMenu(sessionInfo) {
    return PopupMenuButton<String>(
            itemBuilder: (BuildContext context) {
              return sessionInfo.matriculaList.map((dynamic matricula) {
                return PopupMenuItem<String>(
                  value: matricula,
                  child: Text(matricula[""]),
                  onTap: setCurrentMatricula(sessionInfo.matriculaList[index]),
                );
              }).toList();
            },
          );}
    