import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import '../../../core/SharedPref.dart';
import '../../../domain/repositories/auth_repository.dart';
import '../../../domain/usecases/authentication_case_use.dart';
import '../../blocs/login/login_bloc.dart';
import '../../widgets/toast.dart';
import 'recuperarPassword.dart';

class LoginScreen extends StatefulWidget {
  const LoginScreen({Key? key}) : super(key: key);

  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _passwordController = TextEditingController();
  bool _isObscure = true;
  dynamic user;
  late LoginBloc _loginBloc;

  @override
  void initState() {
    super.initState();
    _loginBloc = LoginBloc(
      authUseCase: LoginUseCase(
        authRepository: context.read<AuthRepository>(),
      ),
    );
    getDataUser();
  }

  /*_handleLoginDB(BuildContext context, usuario, pass) async {
    var body = {'username': usuario, 'password': pass};
    await showPresent('');
    var _apiResponse = await apiResponse.getLoginDB(context, usuario, pass);
    /*print('apiiii');
    print(_apiResponse);*/
    if (_apiResponse == null) {
      await dismissPresent();
    } else {
      await sharedPrefs.save('user', usuario);
      await sharedPrefs.save('passw', pass);
      await sharedPrefs.save('login', 'yes');
      //await sharedPrefs.save('usuario', jsonEncode(_apiResponse['user']));
      await sharedPrefs.save('usuario', _apiResponse['user']['nameAndSurname']);
      await dismissPresent();
      Navigator.pushAndRemoveUntil(
        context,
        MaterialPageRoute<void>(
          builder: (BuildContext context) => const HomeScreen(),
        ),
        ModalRoute.withName('/home'),
      );
    }
  }*/

  getDataUser() {
    if (sharedPrefs.containsKey('user') == true &&
        sharedPrefs.containsKey('passw') == true) {
      setState(() {
        _nameController.text = sharedPrefs.read('user');
        _passwordController.text = sharedPrefs.read('passw');
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        body: ListView(
          children: <Widget>[
            Container(
              alignment: Alignment.center,
              padding: const EdgeInsets.only(top: 30, bottom: 30),
              child: ClipRRect(
                child: Image.asset(
                  'assets/e-tramite-logo.png',
                  width: MediaQuery.of(context).size.width / 2.5,
                ),
              ),
            ),
            Center(
              child: Container(
                width: MediaQuery.of(context).size.width * 0.95,
                decoration: BoxDecoration(
                  borderRadius: const BorderRadius.all(Radius.circular(5)),
                  color: Theme.of(context).cardColor,
                ),
                child: Container(
                  padding: const EdgeInsets.only(
                      top: 20, bottom: 5, left: 10, right: 10),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      const Text(
                        'Inicia sesión',
                        style: TextStyle(fontSize: 14),
                      ),
                      const SizedBox(
                        height: 20,
                      ),
                      TextField(
                        controller: _nameController,
                        decoration: const InputDecoration(
                          //labelText: 'Usuario',
                          hintText: 'Usuario',
                          isDense: true,
                          prefixIcon: Icon(
                            Icons.person,
                            size: 22,
                          ),
                        ),
                      ),
                      const SizedBox(
                        height: 20,
                      ),
                      TextField(
                        obscureText: _isObscure,
                        controller: _passwordController,
                        decoration: InputDecoration(
                          prefixIcon: const Icon(
                            Icons.lock_sharp,
                            size: 22,
                          ),
                          isDense: true,
                          suffixIcon: IconButton(
                            icon: Icon(
                              _isObscure
                                  ? Icons.visibility
                                  : Icons.visibility_off,
                              size: 22,
                            ),
                            onPressed: () => setState(
                              () {
                                _isObscure = !_isObscure;
                              },
                            ),
                          ),
                          hintText: 'Contraseña',
                        ),
                      ),
                      const SizedBox(
                        height: 20,
                      ),
                      TextButton(
                        child: const Text(
                          '¿Olvidaste tu contraseña?',
                        ),
                        onPressed: () {
                          showDialog(
                            context: context,
                            builder: (BuildContext context) {
                              return buildDialogPage(context);
                            },
                          );
                        },
                      ),
                      ElevatedButton(
                        child: const Text(
                          'INICIAR SESIÓN',
                        ),
                        onPressed: () {
                          print(_nameController.text);
                          print(_passwordController.text);
                          if (_nameController.text != '' &&
                              _passwordController.text != '') {
                            /*_handleLoginDB(context, _nameController.text,
                                  _passwordController.text);*/
                          } else {
                            showToastError('Complete todos los campos');
                          }
                        },
                      ),
                      const SizedBox(
                        height: 15,
                      ),
                    ],
                  ),
                ),
              ),
            ),
            const SizedBox(
              height: 12,
            )
          ],
        ),
      ),
    );
  }
}
