import 'dart:convert';
import 'package:ealu_flutter/presentation/widgets/optionsGradient.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import '../../core/AppTheme.dart';
import '../../core/SharedPref.dart';

class DrawerMenu extends StatelessWidget {
  const DrawerMenu({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Drawer(
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.only(topRight: Radius.circular(50)),
        ),
        backgroundColor: Colors.white,
        child: Wrap(
          children: <Widget>[
            Padding(
              padding: const EdgeInsets.all(12),
              child: Center(
                child: Image.asset(
                  'assets/ealu_logo.png',
                  width: MediaQuery.of(context).size.width * 0.5,
                  height: MediaQuery.of(context).size.height * 0.23,
                ),
              ),
            ),
            _buildDrawerInstitucion(),
            optionsGradient(
                context, "", MediaQuery.of(context).size.width * 0.08),
            /*dividerCommon(
              context,
              MediaQuery.of(context).size.width * 0.08,
              MediaQuery.of(context).size.width * 0.08,
            ),*/
            _buildDrawerItem(
                icon: FontAwesomeIcons.bookBookmark,
                text: 'Mis Reservas',
                size: 22,
                onTap: () => {
                      Navigator.pushReplacementNamed(
                          context, '/reservasCreadas')
                    }),
            _buildDrawerItem(
                icon: FontAwesomeIcons.bookOpen,
                text: 'Mis Préstamos',
                size: 22,
                onTap: () => {
                      Navigator.pushReplacementNamed(
                          context, '/prestamosWithFilter')
                    }),
            _buildDrawerItem(
                icon: FontAwesomeIcons.moneyBill,
                text: 'Mis Multas',
                size: 22,
                onTap: () =>
                    {Navigator.pushReplacementNamed(context, '/multas')}),
            _buildDrawerItem(
                icon: const IconData(0xf5d2, fontFamily: 'MaterialIcons'),
                size: 24,
                text: 'Nueva Reserva',
                onTap: () => {
                      Navigator.pushReplacementNamed(
                          context, '/reservarWithFilter')
                    }),
            _buildDrawerItem(
                icon: const IconData(0xf521, fontFamily: 'MaterialIcons'),
                text: 'Mi Perfil',
                size: 26,
                onTap: () =>
                    {Navigator.pushReplacementNamed(context, '/perfil')}),
            /*dividerCommon(
              context,
              MediaQuery.of(context).size.width * 0.08,
              MediaQuery.of(context).size.width * 0.08,
            ),*/
            optionsGradient(
                context, "", MediaQuery.of(context).size.width * 0.08),
            _buildDrawerItem(
              icon: FontAwesomeIcons.arrowRightFromBracket,
              text: 'Cerrar Sesión',
              size: 20,
              onTap: () {},
              //onTap: () => logout(context),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildDrawerInstitucion() {
    var ins = jsonDecode(sharedPrefs.read('institucion'));
    return ListTile(
      dense: true,
      contentPadding: const EdgeInsets.only(
        left: 28,
        right: 25,
      ),
      visualDensity: const VisualDensity(horizontal: -4, vertical: 0),
      leading: const Icon(
        FontAwesomeIcons.buildingColumns,
        size: 22,
        color: Color(0xFF99ABC0),
      ),
      title: Text(
        ins['nombre'],
        style: const TextStyle(
          color: Colors.black54,
          fontWeight: FontWeight.bold,
          fontSize: 14,
        ),
      ),
    );
  }

  Widget _buildDrawerItem(
      {required IconData icon,
      required String text,
      required GestureTapCallback onTap,
      required double size}) {
    return GestureDetector(
      onTap: onTap,
      child: ListTile(
        dense: true,
        contentPadding: const EdgeInsets.only(
          left: 28,
        ),
        visualDensity: const VisualDensity(horizontal: -4, vertical: 0),
        leading: Icon(
          icon,
          size: size,
          color: AppTheme.getSecondaryColor(),
        ),
        title: Text(
          text,
          style: const TextStyle(
            color: Colors.black54,
            fontWeight: FontWeight.bold,
            fontSize: 16,
          ),
        ),
      ),
    );
  }
}
